
/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999  Matt Eagleson (e.Messiah@superpimp.org)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

//#include <string.h>
//#include <signal.h>
#include <gnome.h>
#include <gtk/gtk.h>
#include <libgnomeui/gnome-stock.h>
#include "pan.h"
#include "xpm/pan.xpm"

static void guru_finish(GnomeGuru * guru, GtkWidget * destroyme)
{
	guru_data *g;
	gchar *profile_name, *server_address, *server_port, *server_username,
		*server_password;
	gchar *full_name, *email, *organization;
	gchar buf[256];

	g = gtk_object_get_data(GTK_OBJECT(guru), "data");

	profile_name = gtk_entry_get_text(GTK_ENTRY(g->profile_name));
	server_address = gtk_entry_get_text(GTK_ENTRY(g->server_address));
	server_port = gtk_entry_get_text(GTK_ENTRY(g->server_port));
	server_username = gtk_entry_get_text(GTK_ENTRY(g->server_username));
	server_password = gtk_entry_get_text(GTK_ENTRY(g->server_password));
	full_name = gtk_entry_get_text(GTK_ENTRY(g->full_name));
	email = gtk_entry_get_text(GTK_ENTRY(g->email));
	organization = gtk_entry_get_text(GTK_ENTRY(g->organization));

	if (profile_name && server_address && server_port) {
		gnome_config_set_string("/Pan/Servers/Names", profile_name);
		gnome_config_set_string("/Pan/Servers/Active", profile_name);
		g_snprintf(buf, 256, "/Pan/%s/Address", profile_name);
		gnome_config_set_string(buf, server_address);
		g_snprintf(buf, 256, "/Pan/%s/Port", profile_name);
		gnome_config_set_string(buf, server_port);

		/* putting this in a second if, since they're optional */
		if (server_username && server_password) {
			g_snprintf(buf, 256, "/Pan/%s/Username", profile_name);
			gnome_config_set_string(buf, server_username);
			g_snprintf(buf, 256, "/Pan/%s/Password", profile_name);
			gnome_config_set_string(buf, server_password);
		}
	}
	gnome_config_set_string("/Pan/User/Full_Name", full_name);
	gnome_config_set_string("/Pan/User/Email", email);
	gnome_config_set_string("/Pan/User/Organization", organization);
	gnome_config_sync();
	gtk_widget_destroy(g->profile_name);
	gtk_widget_destroy(g->server_address);
	gtk_widget_destroy(g->server_port);
	gtk_widget_destroy(g->server_username);
	gtk_widget_destroy(g->server_password);
	gtk_widget_destroy(g->full_name);
	gtk_widget_destroy(g->email);
	gtk_widget_destroy(g->organization);
	gtk_object_remove_data(GTK_OBJECT(guru), "data");
	g_free(g);
	gtk_widget_destroy(destroyme);

	pan_init();
}

static void guru_cancel(GnomeGuru * guru, GtkWidget * destroyme)
{
	gtk_widget_destroy(destroyme);
}

static GtkWidget *guru_server_page(guru_data * g)
{
	GtkWidget *table;
	GtkWidget *label;

	table = gtk_table_new(6, 2, FALSE);
	gtk_table_set_row_spacings(GTK_TABLE(table), 2);
	gtk_table_set_col_spacings(GTK_TABLE(table), 2);

	label = gtk_label_new
		(_("Let's begin by making a profile for your news server.\n\n"));
	gtk_widget_show(label);
	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
	gtk_table_attach(GTK_TABLE(table), label, 0, 2, 0, 1,
					 GTK_FILL | GTK_EXPAND, GTK_FILL, 4, 0);

/* Server Profile Name */
	label = gtk_label_new(_("Server Profile Name:"));
	gtk_widget_show(label);
	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
					 GTK_FILL, GTK_FILL, 4, 0);

	g->profile_name = gtk_entry_new();
	gtk_entry_set_text(GTK_ENTRY(g->profile_name), _("Default"));
	gtk_widget_show(g->profile_name);
	gtk_table_attach(GTK_TABLE(table), g->profile_name, 1, 2, 1, 2,
					 GTK_FILL | GTK_EXPAND, GTK_FILL, 4, 0);

/* Server Address */
	label = gtk_label_new(_("Server Address:"));
	gtk_widget_show(label);
	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,
					 GTK_FILL, GTK_FILL, 4, 0);

	g->server_address = gtk_entry_new();
	gtk_entry_set_text(GTK_ENTRY(g->server_address), "news");
	gtk_widget_show(g->server_address);
	gtk_table_attach(GTK_TABLE(table), g->server_address, 1, 2, 2, 3,
					 GTK_FILL | GTK_EXPAND, GTK_FILL, 4, 0);

/* Server Port */
	label = gtk_label_new(_("Server Port:"));
	gtk_widget_show(label);
	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4,
					 GTK_FILL, GTK_FILL, 4, 0);

	g->server_port = gtk_entry_new();
	gtk_entry_set_text(GTK_ENTRY(g->server_port), "119");
	gtk_widget_show(g->server_port);
	gtk_table_attach(GTK_TABLE(table), g->server_port, 1, 2, 3, 4,
					 GTK_FILL | GTK_EXPAND, GTK_FILL, 4, 0);
/* Server Username */
	label = gtk_label_new(_("Username:"));
	gtk_widget_show(label);
	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 4, 5,
					 GTK_FILL, GTK_FILL, 4, 0);

	g->server_username = gtk_entry_new();
	gtk_entry_set_text(GTK_ENTRY(g->server_username), "");
	gtk_widget_show(g->server_username);
	gtk_table_attach(GTK_TABLE(table), g->server_username, 1, 2, 4, 5,
					 GTK_FILL | GTK_EXPAND, GTK_FILL, 4, 0);

/* Server Password */
	label = gtk_label_new(_("Password:"));
	gtk_widget_show(label);
	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 5, 6,
					 GTK_FILL, GTK_FILL, 4, 0);

	g->server_password = gtk_entry_new();
	gtk_entry_set_text(GTK_ENTRY(g->server_password), "");
	gtk_entry_set_visibility(GTK_ENTRY(g->server_password), FALSE);
	gtk_widget_show(g->server_password);
	gtk_table_attach(GTK_TABLE(table), g->server_password, 1, 2, 5, 6,
					 GTK_FILL | GTK_EXPAND, GTK_FILL, 4, 0);

	return table;
}

static GtkWidget *guru_user_page(guru_data * g)
{
	GtkWidget *table;
	GtkWidget *label;

	table = gtk_table_new(4, 2, FALSE);
	gtk_table_set_row_spacings(GTK_TABLE(table), 2);
	gtk_table_set_col_spacings(GTK_TABLE(table), 2);

	label = gtk_label_new
		(_("The following user information would be nice to have.\n\n"));
	gtk_widget_show(label);
	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
	gtk_table_attach(GTK_TABLE(table), label, 0, 2, 0, 1,
					 GTK_FILL | GTK_EXPAND, GTK_FILL, 4, 0);

	label = gtk_label_new(_("Full Name:"));
	gtk_widget_show(label);
	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 1, 2,
					 GTK_FILL, GTK_FILL, 4, 0);

	g->full_name = gtk_entry_new();
	gtk_widget_show(g->full_name);
	gtk_table_attach(GTK_TABLE(table), g->full_name, 1, 2, 1, 2,
					 GTK_FILL | GTK_EXPAND, GTK_FILL, 4, 0);

	label = gtk_label_new(_("Email Address:"));
	gtk_widget_show(label);
	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 2, 3,
					 GTK_FILL, GTK_FILL, 4, 0);

	g->email = gtk_entry_new();
	gtk_widget_show(g->email);
	gtk_table_attach(GTK_TABLE(table), g->email, 1, 2, 2, 3,
					 GTK_FILL | GTK_EXPAND, GTK_FILL, 4, 0);

	label = gtk_label_new(_("Organization:"));
	gtk_widget_show(label);
	gtk_misc_set_alignment(GTK_MISC(label), 0.0, 0.5);
	gtk_table_attach(GTK_TABLE(table), label, 0, 1, 3, 4,
					 GTK_FILL, GTK_FILL, 4, 0);

	g->organization = gtk_entry_new();
	gtk_widget_show(g->organization);
	gtk_table_attach(GTK_TABLE(table), g->organization, 1, 2, 3, 4,
					 GTK_FILL | GTK_EXPAND, GTK_FILL, 4, 0);

	return table;
}

void guru_spawn(void)
{
	GtkWidget *guru;
	GtkWidget *page;
	GtkWidget *dialog;
	GtkWidget *graphic;
	guru_data *g;

	g = (guru_data *) g_malloc(sizeof(guru_data));

	dialog = gnome_dialog_new(_("Welcome to Pan"), NULL);
	gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);

	graphic = gnome_pixmap_new_from_xpm_d(pan_xpm);

	guru =
		gnome_guru_new(_("Welcome to Pan"), graphic, GNOME_DIALOG(dialog));

	gtk_object_set_data(GTK_OBJECT(guru), "data", g);

	page = guru_server_page(g);
	gnome_guru_append_page(GNOME_GURU(guru), _("Server Profile"), page);
	page = guru_user_page(g);
	gnome_guru_append_page(GNOME_GURU(guru), _("User Information"), page);

	gtk_signal_connect(GTK_OBJECT(guru), "finished",
					   GTK_SIGNAL_FUNC(guru_finish), dialog);

	gtk_signal_connect(GTK_OBJECT(guru), "cancelled",
					   GTK_SIGNAL_FUNC(guru_cancel), dialog);

	gtk_widget_show(guru);
	gtk_widget_show(dialog);
}
